<?php

/*
 * @package Track User Logins
 * @version 1.1
 * @autor margarett (Bruno Alves) for SimpleMachines www.simplemachines.org
 * @license http://creativecommons.org/licenses/by/3.0
 */

function add_track_logins_menu(&$profile_areas)
{

	global $txt;

	$profile_areas['info']['areas']['tracking']['subsections']['logins'] = array(
		$txt['trackLogins'], 'moderate_forum',
	);
}

//Add to database the login/logout
function trackLogins_add($memID, $action = '', $ip = '')
{
	global $smcFunc;
	//This shouldn't happen...
	if (empty($memID) || empty($action))
		return;
	
	//Add this record to the log logins table
	$smcFunc['db_insert']('',
		'{db_prefix}log_logins',
		array(
			'id_member' => 'int',
			'date' => 'int',
			'action' => 'string',
			'ip' => 'string',
		),		
		array($memID, time(), $action, $ip),
		array('id_log')
	); 
}

function trackLogins($memID)
{
	global $scripturl, $txt, $modSettings, $sourcedir, $context;

	// Verify if the user has sufficient permissions.
	isAllowedTo('moderate_forum');

	// Set the options for the list component.
	$listOptions = array(
		'id' => 'track_user_logins',
		'title' => $txt['trackLogins_by'] . ' ' . $context['member']['name'],
		'items_per_page' => $modSettings['defaultMaxMessages'],
		'no_items_label' => $txt['trackLogins_nodata'],
		'base_href' => $scripturl . '?action=profile;area=tracking;sa=logins;u=' . $memID,
		'default_sort_col' => 'date',
		'get_items' => array(
			'function' => 'list_getLogins',
			'params' => array(
				'le.id_member = {int:current_member}',
				array('current_member' => $memID),
			),
		),
		'get_count' => array(
			'function' => 'list_getLoginsCount',
			'params' => array(
				'id_member = {int:current_member}',
				array('current_member' => $memID),
			),
		),
		'columns' => array(
			'date' => array(
				'header' => array(
					'value' => $txt['date'],
				),
				'data' => array(
					'db' => 'date',
				),
				'sort' => array(
					'default' => 'le.id_log DESC',
					'reverse' => 'le.id_log',
				),
			),
			'action' => array(
				'header' => array(
					'value' => $txt['trackLogins_action'],
				),
				'data' => array(
					'db' => 'action',
				),
				'sort' => array(
				),
			),
			'ip' => array(
				'header' => array(
					'value' => $txt['ip'],
				),
				'data' => array(
					'db' => 'ip',
				),
				'sort' => array(
				),
			),
		),
	);

	// Create the list for viewing.
	require_once($sourcedir . '/Subs-List.php');
	createList($listOptions);

}

function list_getLoginsCount($where, $where_vars = array())
{
	global $smcFunc;

	$request = $smcFunc['db_query']('', '
		SELECT COUNT(*) AS total
		FROM {db_prefix}log_logins
		WHERE ' . $where,
		$where_vars
	);
	list ($count) = $smcFunc['db_fetch_row']($request);
	$smcFunc['db_free_result']($request);

	return $count;
}

function list_getLogins($start, $items_per_page, $sort, $where, $where_vars = array())
{
	global $smcFunc, $txt, $scripturl;

	// Get a list of error messages from this ip (range).
	$request = $smcFunc['db_query']('', '
		SELECT
			le.date, le.action, le.ip, le.id_member
		FROM {db_prefix}log_logins AS le
		WHERE ' . $where . '
		ORDER BY ' . $sort . '
		LIMIT ' . $start . ', ' . $items_per_page,
		array_merge($where_vars, array(
			'guest_title' => $txt['guest_title'],
		))
	);
	$logins = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{
		$temp = 'trackLogins_' . $row['action'];
		$logins[] = array(
			'date' => timeformat($row['date']),
			'action' => $txt[$temp],
			'ip' => empty($row['ip']) ? '' : '<a href="' . $scripturl . '?action=profile;area=tracking;sa=ip;searchip=' . $row['ip'] . ';u=' . $row['id_member'] . '">' . $row['ip'] . '</a>',
		);
	}
	$smcFunc['db_free_result']($request);

	return $logins;
}

?>